<?php
/**
 * The Excel exporter currently is just a tab-delimited export.
 */
class webform_google_exporter extends webform_exporter_delimited {
  private $options;

  function webform_google_exporter($options) {
    $options['delimiter'] = '\t';
    $this->options = $options;
    parent::webform_exporter_delimited($options);
  }

  function add_row(&$file_handle, $data) {
    foreach ($data as $key => $value) {
      // Remove any tabs and new lines in the submitted data. Google does not
      // support importing quoted data, so we can't preserve them.
      $data[$key] = str_replace("\t", '  ', $data[$key]);
      $data[$key] = str_replace("\r", '', $data[$key]);
      $data[$key] = str_replace("\n", ' ', $data[$key]);
    }
    $row = implode($this->delimiter, $data) . "\n";

    if (function_exists('mb_convert_encoding')) {
      $row = mb_convert_encoding($row, 'UTF-16LE', 'UTF-8');
    }

    @fwrite($file_handle, $row);
  }

  function download($node) {
    // For headers on this file, we actually redirect the user to Google's
    // authentication page. Then the menu handler at webform/google-exporter
    // then will actually do the work of transfering the current file to Google.
    $query = array(
      'response_type' => 'code',
      'redirect_uri' => url('webform/google-exporter', array('absolute' => TRUE)),
      'client_id' => variable_get('webform_google_exporter_client_id', NULL),
      'scope' => 'https://www.googleapis.com/auth/drive.file',
    );

    // Save information about the export to the session while we authenticate.
    $_SESSION['webform_google_exporter'] = array(
      'nid' => $node->nid,
      'file' => $this->options['file_name'],
    );

    drupal_goto('https://www.google.com/accounts/o8/oauth2/authorization', array('query' => $query));
  }
}
